(function ($) {
    if (typeof(String.prototype.trim) === "undefined") {
        String.prototype.trim = function () {
            return String(this).replace(/^\s+|\s+$/g, '');
        };
    }

    var CONFIG_PADRAO = {
        DEBUG: true,
        entrada: '[data-historico_desfazer="entrada"]',
        saida: '[data-historico_desfazer="saida"]',
        historico: '[data-historico_desfazer="historico"]',
        btn_visualizar: '[data-historico_desfazer="btn_visualizar"]',
        btn_apagar: '[data-historico_desfazer="btn_apagar"]',
        btn_desfazer: '[data-historico_desfazer="btn_desfazer"]'
    };

    // inicializa uma simples função (vai servir como INICIALIZAÇÃO)
    var Plugin1 = function (noh, configs) {

        this.$elemento = $(noh);
        this.opcoes = $.extend({}, this.CONFIGS_PADRAO, configs);

        // armazena o texto atual sendo exibido na(s) saída(s)
        this.texto_atual = '';

        // armazena os históricos (textos) à medida que forem apagando
        // ou vai removendo 1 a 1 à medida que 'desfazer'
        this.historico = [];

        // inicializa os objetos
        this.$entrada = this.$elemento.find(this.opcoes.entrada);
        this.$saida = this.$elemento.find(this.opcoes.saida);
        this.$historico = this.$elemento.find(this.opcoes.historico);
        this.$btn_visualizar = this.$elemento.find(this.opcoes.btn_visualizar);
        this.$btn_apagar = this.$elemento.find(this.opcoes.btn_apagar);
        this.$btn_desfazer = this.$elemento.find(this.opcoes.btn_desfazer);

        this.configura();
    };

    // iniciando os MÉTODOS para a função Plugin (futura classe)
    Plugin1.prototype = {
        CONFIGS_PADRAO: CONFIG_PADRAO,
        debug: function (t) {
            var self = this;
            if (self.opcoes.DEBUG) {
                if (console && console.log) {
                    console.log(t);
                } else {
                    alert('Console não habilitado!!!')
                }
            }
        },
        configura: function () {
            var self = this;

            // configura os ESTADOS iniciais:
            // 1 - espaços

            self.$entrada
                .val('');

            self.$saida
                .html('');

            self.$historico
                .empty()
                .append(
                    self.template_historico_vazio()
                );

            // 2 - dos botoes
            self.$btn_apagar.attr('disabled', 'disabled');
            self.efeito_apagar_desativar();

            self.$btn_desfazer.attr('disabled', 'disabled');
            self.efeito_desfazer_desativar();

            // realiza os binds necessários
            self.$elemento
                .on(
                    'keyup',
                    self.opcoes.entrada,
                    $.proxy(self.evento_entrada_keyup, self)
                );

            self.$elemento
                .on(
                    'click',
                    self.opcoes.btn_visualizar,
                    $.proxy(self.evento_btn_visualizar_click, self)
                );

            self.$elemento
                .on(
                    'click',
                    self.opcoes.btn_apagar,
                    $.proxy(self.evento_btn_apagar_click, self)
                );

            self.$elemento
                .on(
                    'click',
                    self.opcoes.btn_desfazer,
                    $.proxy(self.evento_btn_desfazer_click, self)
                );
        },
        // ***** PROCESSAMENTO *****
        processa_entrada: function (novo_texto) {
            var self = this;

            // se houver texto_atual em exibição
            if (self.texto_atual) {
                // se não houver histiroco anterior
                if (!self.historico.length){
                    //limpa a area do historico
                    self.$historico.empty();

                }

                // adiciona ao historico antes de
                // sobreescrever com o novo texto chegando
                self
                    .historico
                    .push(self.texto_atual);

                self.$historico.prepend(
                    self.template_historico_add_linha(
                        self.texto_atual
                    )
                )
            }

            // exibe o novo texto
            self.template_escreve_saida(novo_texto);

            self.texto_atual = novo_texto;

            // se houver 'novo_texto'...
            if (novo_texto) {
                // ...habilita o botao Apagar
                self.$btn_apagar.removeAttr('disabled');
                self.efeito_apagar_ativar();
            }
            // ...se não...
            else {
                // ...desabilita o botão Apagar
                self.$btn_apagar.attr('disabled', 'disabled');
                self.efeito_apagar_desativar();
            }

            // se houver historico...
            if (self.historico.length) {
                // Habilita o botão Desfazer
                self.$btn_desfazer.removeAttr('disabled');
                self.efeito_desfazer_ativar();
            }
        },
        processa_desfazer: function () {
            var self = this;

            // tem algum historico???
            if (self.historico.length) {

                var texto_antigo = self.historico.pop();

                self.template_escreve_saida(texto_antigo);
                self.texto_atual = texto_antigo;

                // remove o item do historico
                self.template_historico_del_linha(texto_antigo);

                // Habilita o botão Apagar
                self.$btn_apagar.removeAttr('disabled');
                self.efeito_apagar_ativar();
            }

            // se acabou os historicos...
            if (!self.historico.length) {
                // coloca o template do historico vazio
                self.$historico
                    .empty()
                    .append(
                        self.template_historico_vazio()
                    );

                // Desabilita o botão Desfazer
                self.$btn_desfazer.attr('disabled', 'disabled');
                self.efeito_desfazer_desativar();
            }
        },
        // ***** EVENTOS *****
        evento_entrada_keyup: function (e) {
            var self = this;
            if (e.which == 13) {
                self.processa_entrada(self.$entrada.val());

                // limpa o texto
                self.$entrada.val('');
            }
        },
        evento_btn_visualizar_click: function (e) {
            var self = this;
            self.processa_entrada(self.$entrada.val());

            // limpa o texto
            self.$entrada.val('');
        },
        evento_btn_apagar_click: function (e) {
            var self = this;

            if (!self.$btn_apagar.is('[disabled]')) {
                // processa o texto como sendo em branco
                self.processa_entrada('');
            }
        },
        evento_btn_desfazer_click: function (e) {
            var self = this;

            // se o botao Desfazer NÃO estiver desabilitado
            if (!self.$btn_desfazer.is('[disabled]')) {
                // processa a Recuperação do texto
                // do histórico para a saída
                self.processa_desfazer();
            }
        },
        // ***** EFEITOS (css) *****
        efeito_apagar_ativar: function () {
            // neste caso, vou mudar a classe do botao (cor)
            var self = this;
            self.$btn_apagar
                .removeClass('btn-secondary')
                .addClass('btn-outline-danger')
        },
        efeito_apagar_desativar: function () {
            // neste caso, vou mudar a classe do botao (cor)
            var self = this;
            self.$btn_apagar
                .removeClass('btn-outline-danger')
                .addClass('btn-secondary')
        },
        efeito_desfazer_ativar: function () {
            // neste caso, vou mudar a classe do botao (cor)
            var self = this;
            self.$btn_desfazer
                .removeClass('btn-secondary')
                .addClass('btn-outline-success')
        },
        efeito_desfazer_desativar: function () {
            // neste caso, vou mudar a classe do botao (cor)
            var self = this;
            self.$btn_desfazer
                .addClass('btn-secondary')
                .removeClass('btn-outline-success')
        },
        // ***** TEMPLATES *****
        template_escreve_saida: function (texto) {
            // por mais que aqui eu não use o template agora
            // ele fica disponível para o customizar
            var self = this;
            self.$saida.empty().html(texto);
        },
        template_historico_del_linha: function (texto) {
            var self = this;

            // como o leiaute usa LISTA (não preciso usar o TEXTO)
            // vou pegar o primeiro item e remover ele
            self.$historico.find(':first').remove();
        },
        template_historico_add_linha: function (texto) {
            return '<li>' + texto + '</li>';
        },
        template_historico_vazio: function () {
            return '<li class="text-muted">(vazio)</li>';
        }
    };

    // -------------------------------------------------------
    // 1ª maneira de usar o plugin (através do new meu_plugin)
    // -------------------------------------------------------
    window.meu_plugin = Plugin1;

    // ------------------------------------------------
    // 2º maneira de usar o plugin (através do JQUERY)
    // ------------------------------------------------
    $.fn.meu_plugin = function (config) {
        return this.each(function () {
            // checa se o nó (da DOM) já foi inicializado anteriormente
            var data = $(this).data('meu_plugin');

            if (!data) {
                data = new Plugin1(this, config);
                $(this).data('meu_plugin', data);
            }
        });
    }
})(jQuery);